@@ -371,10 +371,11 @@ def outdated_pypi_packages(msl_installed=None):
         The information about the PyPI packages that are outdated.
     """
     pkgs_to_update = dict()
+    log.debug('Checking PyPI for all non-MSL packages that are outdated')
     try:
         output = subprocess.check_output([sys.executable, '-m', 'pip', 'list', '--outdated'])
     except subprocess.CalledProcessError as e:
-        log.error('ERROR: "pip list --outdated" invalid -> {}'.format(e))
+        log.error('ERROR: processing "pip list --outdated" raised -> {}'.format(e))
         return pkgs_to_update
 
     lines = output.decode().splitlines()
@@ -408,7 +409,14 @@ def outdated_pypi_packages(msl_installed=None):
                         if package in pkgs_to_update:
                             if specifier not in pkgs_to_update[package]['version']:
                                 # multiple version constraints
-                                pkgs_to_update[package]['version'] += ','+specifier
+                                constraints = pkgs_to_update[package]['version']
+                                if constraints[0] not in '<!=>~':
+                                    # then `constraints` corresponds to an exact version
+                                    # and is missing the leading "=="
+                                    new_version = specifier
+                                else:
+                                    new_version = specifier + ',' + constraints
+                                pkgs_to_update[package]['version'] = new_version
                         else:
                             pkgs_to_update[package] = {
                                 'installed_version': outdated['version'],
